@@ -20,9 +20,6 @@
 #include <ctype.h>
 #include <memory.h>
 #include <stdarg.h>
-// This include is required in order for content_decryption_module to work // on
-// Unix systems.
-#include <stddef.h>
 #include <stdint.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -33,14 +30,15 @@
 #include <sstream>
 #include <vector>
 
+#include "pk11pub.h"
+#include "prerror.h"
+#include "secmodt.h"
+
 #include "ArrayUtils.h"
 #include "BigEndian.h"
 #include "ClearKeyBase64.h"
 #include "mozilla/Sprintf.h"
-#include "pk11pub.h"
-#include "prerror.h"
 #include "psshparser/PsshParser.h"
-#include "secmodt.h"
 
 using namespace cdm;
 using std::string;
@@ -141,6 +139,20 @@ bool ClearKeyUtils::DecryptCbcs(const vector<uint8_t>& aKey,
   const uint32_t totalBlocks = aSubsample.Length() / BLOCK_SIZE;
   uint32_t blocksProcessed = 0;
 
+  if (aSkipByteBlock == 0) {
+    // ISO/IEC 23001 - 7 Section 9.6.1
+    // 'When the fields default_crypt_byte_block and default_skip_byte_block in
+    // a version 1 Track Encryption Box('tenc') are non - zero numbers, pattern
+    // encryption SHALL be applied.'
+    // So if both are 0, then everything is encrypted. Similarly, if skip is 0
+    // and crypt is non-0, everything is encrypted.
+    // In this case we can just decrypt all the blocks in one call. This is the
+    // same outcome as decrypting them using smaller steps, as either way the
+    // CBC result should be the same.
+    MOZ_ASSERT(skipBytes == 0);
+    aCryptByteBlock = totalBlocks;
+  }
+
   while (blocksProcessed < totalBlocks) {
     uint32_t blocksToDecrypt = aCryptByteBlock <= totalBlocks - blocksProcessed
                                    ? aCryptByteBlock
@@ -250,7 +262,7 @@ static bool EncodeBase64Web(vector<uint8_t> aBinary, string& aEncoded) {
 void ClearKeyUtils::MakeKeyRequest(const vector<KeyId>& aKeyIDs,
                                    string& aOutRequest,
                                    SessionType aSessionType) {
-  assert(aKeyIDs.size() && aOutRequest.empty());
+  assert(!aKeyIDs.empty() && aOutRequest.empty());
 
   aOutRequest.append("{\"kids\":[");
   for (size_t i = 0; i < aKeyIDs.size(); i++) {
@@ -341,8 +353,6 @@ static bool SkipObject(ParserContext& aCtx) {
     }
     EXPECT_SYMBOL(aCtx, ',');
   }
-
-  return false;
 }
 
 /**
@@ -397,8 +407,6 @@ static bool SkipToken(ParserContext& aCtx) {
     CK_LOGD("JWK parser skipping literal");
     return SkipLiteral(aCtx);
   }
-
-  return false;
 }
 
 static bool GetNextLabel(ParserContext& aCtx, string& aOutLabel) {
