@@ -4,35 +4,26 @@
 
 // Original author: ekr@rtfm.com
 
-#include <iostream>
-
 #include "logging.h"
 #include "nss.h"
+#include "ssl.h"
 
 #include "api/audio_codecs/builtin_audio_decoder_factory.h"
 #include "api/scoped_refptr.h"
-#include "call/call.h"
 #include "AudioSegment.h"
-#include "AudioStreamTrack.h"
-#include "ConcreteConduitControl.h"
+#include "Canonicals.h"
 #include "modules/audio_device/include/fake_audio_device.h"
 #include "modules/audio_mixer/audio_mixer_impl.h"
 #include "modules/audio_processing/include/audio_processing.h"
 #include "mozilla/Mutex.h"
 #include "mozilla/RefPtr.h"
-#include "mozilla/ResultVariant.h"
 #include "mozilla/SpinEventLoopUntil.h"
+#include "MediaConduitInterface.h"
 #include "MediaPipeline.h"
 #include "MediaPipelineFilter.h"
 #include "MediaTrackGraph.h"
 #include "MediaTrackListener.h"
-#include "MediaStreamTrack.h"
 #include "TaskQueueWrapper.h"
-#include "transportflow.h"
-#include "transportlayerloopback.h"
-#include "transportlayerdtls.h"
-#include "transportlayersrtp.h"
-#include "mozilla/SyncRunnable.h"
 #include "mtransport_test_utils.h"
 #include "SharedBuffer.h"
 #include "MediaTransportHandler.h"
@@ -53,7 +44,7 @@ class MainAsCurrent : public TaskQueueWrapper<DeletionPolicy::NonBlocking> {
  public:
   MainAsCurrent()
       : TaskQueueWrapper(
-            TaskQueue::Create(do_AddRef(GetMainThreadEventTarget()),
+            TaskQueue::Create(do_AddRef(GetMainThreadSerialEventTarget()),
                               "MainAsCurrentTaskQueue"),
             "MainAsCurrent"_ns),
         mSetter(this) {
@@ -144,9 +135,8 @@ class FakeAudioTrack : public ProcessedMediaTrack {
 
 template <typename Function>
 void RunOnSts(Function&& aFunction) {
-  MOZ_ALWAYS_SUCCEEDS(test_utils->sts_target()->Dispatch(
-      NS_NewRunnableFunction(__func__, [&] { aFunction(); }),
-      nsISerialEventTarget::DISPATCH_SYNC));
+  MOZ_ALWAYS_SUCCEEDS(test_utils->SyncDispatchToSTS(
+      NS_NewRunnableFunction(__func__, [&] { aFunction(); })));
 }
 
 class LoopbackTransport : public MediaTransportHandler {
@@ -251,27 +241,20 @@ class LoopbackTransport : public MediaTransportHandler {
   RefPtr<MediaTransportHandler> peer_;
 };
 
-class NoTrialsConfig : public webrtc::WebRtcKeyValueConfig {
- public:
-  NoTrialsConfig() = default;
-  std::string Lookup(absl::string_view key) const override {
-    return std::string();
-  }
-};
-
 class TestAgent {
  public:
   explicit TestAgent(const RefPtr<SharedWebrtcState>& aSharedState)
-      : conduit_control_(aSharedState->mCallWorkerThread),
+      : control_(aSharedState->mCallWorkerThread),
         audio_config_(109, "opus", 48000, 2, false),
-        call_(WebrtcCallWrapper::Create(mozilla::dom::RTCStatsTimestampMaker(),
-                                        nullptr, aSharedState)),
+        call_(WebrtcCallWrapper::Create(
+            mozilla::dom::RTCStatsTimestampMaker::Create(), nullptr,
+            aSharedState)),
         audio_conduit_(
             AudioSessionConduit::Create(call_, test_utils->sts_target())),
         audio_pipeline_(),
         transport_(new LoopbackTransport) {
     Unused << WaitFor(InvokeAsync(call_->mCallThread, __func__, [&] {
-      audio_conduit_->InitControl(&conduit_control_);
+      audio_conduit_->InitControl(&control_);
       return GenericPromise::CreateAndResolve(true, "TestAgent()");
     }));
   }
@@ -300,15 +283,10 @@ class TestAgent {
   void Stop() {
     MOZ_MTLOG(ML_DEBUG, "Stopping");
 
-    if (audio_pipeline_) {
-      audio_pipeline_->Stop();
-    }
-    if (audio_conduit_) {
-      conduit_control_.Update([](auto& aControl) {
-        aControl.mTransmitting = false;
-        aControl.mReceiving = false;
-      });
-    }
+    control_.Update([](auto& aControl) {
+      aControl.mTransmitting = false;
+      aControl.mReceiving = false;
+    });
   }
 
   void Shutdown_s() { transport_->Shutdown(); }
@@ -328,9 +306,7 @@ class TestAgent {
       audio_track_ = nullptr;
     }
 
-    test_utils->sts_target()->Dispatch(
-        WrapRunnable(this, &TestAgent::Shutdown_s),
-        nsISerialEventTarget::DISPATCH_SYNC);
+    test_utils->SyncDispatchToSTS(WrapRunnable(this, &TestAgent::Shutdown_s));
   }
 
   uint32_t GetRemoteSSRC() {
@@ -356,7 +332,7 @@ class TestAgent {
   }
 
  protected:
-  ConcreteConduitControl conduit_control_;
+  ConcreteControl control_;
   AudioCodecConfig audio_config_;
   RefPtr<WebrtcCallWrapper> call_;
   RefPtr<AudioSessionConduit> audio_conduit_;
@@ -372,7 +348,7 @@ class TestAgentSend : public TestAgent {
  public:
   explicit TestAgentSend(const RefPtr<SharedWebrtcState>& aSharedState)
       : TestAgent(aSharedState) {
-    conduit_control_.Update([&](auto& aControl) {
+    control_.Update([&](auto& aControl) {
       aControl.mAudioSendCodec = Some(audio_config_);
     });
     audio_track_ = new FakeAudioTrack();
@@ -381,18 +357,18 @@ class TestAgentSend : public TestAgent {
   virtual void CreatePipeline(const std::string& aTransportId) {
     std::string test_pc;
 
-    RefPtr<MediaPipelineTransmit> audio_pipeline = new MediaPipelineTransmit(
+    auto audio_pipeline = MakeRefPtr<MediaPipelineTransmit>(
         test_pc, transport_, AbstractThread::MainThread(),
         test_utils->sts_target(), false, audio_conduit_);
+    Unused << WaitFor(InvokeAsync(call_->mCallThread, __func__, [&] {
+      audio_pipeline->InitControl(&control_);
+      return GenericPromise::CreateAndResolve(true, __func__);
+    }));
 
     audio_pipeline->SetSendTrackOverride(audio_track_);
-    audio_pipeline->Start();
-    conduit_control_.Update(
-        [](auto& aControl) { aControl.mTransmitting = true; });
-
+    control_.Update([](auto& aControl) { aControl.mTransmitting = true; });
+    audio_pipeline->UpdateTransport_m(aTransportId, nullptr);
     audio_pipeline_ = audio_pipeline;
-
-    audio_pipeline_->UpdateTransport_m(aTransportId, nullptr);
   }
 };
 
@@ -400,7 +376,7 @@ class TestAgentReceive : public TestAgent {
  public:
   explicit TestAgentReceive(const RefPtr<SharedWebrtcState>& aSharedState)
       : TestAgent(aSharedState) {
-    conduit_control_.Update([&](auto& aControl) {
+    control_.Update([&](auto& aControl) {
       std::vector<AudioCodecConfig> codecs;
       codecs.push_back(audio_config_);
       aControl.mAudioRecvCodecs = codecs;
@@ -410,16 +386,19 @@ class TestAgentReceive : public TestAgent {
   virtual void CreatePipeline(const std::string& aTransportId) {
     std::string test_pc;
 
-    audio_pipeline_ = new MediaPipelineReceiveAudio(
+    auto audio_pipeline = MakeRefPtr<MediaPipelineReceiveAudio>(
         test_pc, transport_, AbstractThread::MainThread(),
         test_utils->sts_target(),
         static_cast<AudioSessionConduit*>(audio_conduit_.get()), nullptr,
-        PRINCIPAL_HANDLE_NONE);
+        TrackingId(), PRINCIPAL_HANDLE_NONE, PrincipalPrivacy::NonPrivate);
+    Unused << WaitFor(InvokeAsync(call_->mCallThread, __func__, [&] {
+      audio_pipeline->InitControl(&control_);
+      return GenericPromise::CreateAndResolve(true, __func__);
+    }));
 
-    audio_pipeline_->Start();
-    conduit_control_.Update([](auto& aControl) { aControl.mReceiving = true; });
-
-    audio_pipeline_->UpdateTransport_m(aTransportId, std::move(bundle_filter_));
+    control_.Update([](auto& aControl) { aControl.mReceiving = true; });
+    audio_pipeline->UpdateTransport_m(aTransportId, std::move(bundle_filter_));
+    audio_pipeline_ = audio_pipeline;
   }
 
   void SetBundleFilter(UniquePtr<MediaPipelineFilter>&& filter) {
@@ -463,7 +442,7 @@ class MediaPipelineTest : public ::testing::Test {
             AbstractThread::MainThread(), CreateAudioStateConfig(),
             already_AddRefed(
                 webrtc::CreateBuiltinAudioDecoderFactory().release()),
-            WrapUnique(new NoTrialsConfig()))),
+            WrapUnique(new webrtc::NoTrialsConfig()))),
         p1_(shared_state_),
         p2_(shared_state_) {}
 
@@ -480,9 +459,8 @@ class MediaPipelineTest : public ::testing::Test {
 
   // Setup transport.
   void InitTransports() {
-    test_utils->sts_target()->Dispatch(
-        WrapRunnableNM(&TestAgent::Connect, &p2_, &p1_),
-        nsISerialEventTarget::DISPATCH_SYNC);
+    test_utils->SyncDispatchToSTS(
+        WrapRunnableNM(&TestAgent::Connect, &p2_, &p1_));
   }
 
   // Verify RTP and RTCP
